==> huaweicloudsdkbssintl-3.0.52-py2.py3-none-any.whl: huaweicloudsdkbssintl/v2/model/error_detail.py <==
# coding: utf-8

import re
import six





class ErrorDetail:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'error_code': 'str',
        'error_msg': 'str',
        'id': 'str'
    }

    attribute_map = {
        'error_code': 'error_code',
        'error_msg': 'error_msg',
        'id': 'id'
    }

    def __init__(self, error_code=None, error_msg=None, id=None):
        """ErrorDetail - a model defined in huaweicloud sdk"""
        
        

        self._error_code = None
        self._error_msg = None
        self._id = None
        self.discriminator = None

        if error_code is not None:
            self.error_code = error_code
        if error_msg is not None:
            self.error_msg = error_msg
        if id is not None:
            self.id = id

    @property
    def error_code(self):
        """Gets the error_code of this ErrorDetail.

        |参数名称：返回码| |参数的约束及描述：该参数非必填，最大长度16|

        :return: The error_code of this ErrorDetail.
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this ErrorDetail.

        |参数名称：返回码| |参数的约束及描述：该参数非必填，最大长度16|

        :param error_code: The error_code of this ErrorDetail.
        :type: str
        """
        self._error_code = error_code

    @property
    def error_msg(self):
        """Gets the error_msg of this ErrorDetail.

        |参数名称：返回码描述| |参数的约束及描述：该参数非必填，最大长度1024|

        :return: The error_msg of this ErrorDetail.
        :rtype: str
        """
        return self._error_msg

    @error_msg.setter
    def error_msg(self, error_msg):
        """Sets the error_msg of this ErrorDetail.

        |参数名称：返回码描述| |参数的约束及描述：该参数非必填，最大长度1024|

        :param error_msg: The error_msg of this ErrorDetail.
        :type: str
        """
        self._error_msg = error_msg

    @property
    def id(self):
        """Gets the id of this ErrorDetail.

        |参数名称：标示ID| |参数的约束及描述：该参数非必填，最大长度256|

        :return: The id of this ErrorDetail.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ErrorDetail.

        |参数名称：标示ID| |参数的约束及描述：该参数非必填，最大长度256|

        :param id: The id of this ErrorDetail.
        :type: str
        """
        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ErrorDetail):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkbssintl-3.0.53-py2.py3-none-any.whl: huaweicloudsdkbssintl/v2/model/error_detail.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ErrorDetail:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'error_code': 'str',
        'error_msg': 'str',
        'id': 'str'
    }

    attribute_map = {
        'error_code': 'error_code',
        'error_msg': 'error_msg',
        'id': 'id'
    }

    def __init__(self, error_code=None, error_msg=None, id=None):
        """ErrorDetail - a model defined in huaweicloud sdk"""
        
        

        self._error_code = None
        self._error_msg = None
        self._id = None
        self.discriminator = None

        if error_code is not None:
            self.error_code = error_code
        if error_msg is not None:
            self.error_msg = error_msg
        if id is not None:
            self.id = id

    @property
    def error_code(self):
        """Gets the error_code of this ErrorDetail.

        |参数名称：返回码| |参数的约束及描述：该参数非必填，最大长度16|

        :return: The error_code of this ErrorDetail.
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this ErrorDetail.

        |参数名称：返回码| |参数的约束及描述：该参数非必填，最大长度16|

        :param error_code: The error_code of this ErrorDetail.
        :type: str
        """
        self._error_code = error_code

    @property
    def error_msg(self):
        """Gets the error_msg of this ErrorDetail.

        |参数名称：返回码描述| |参数的约束及描述：该参数非必填，最大长度1024|

        :return: The error_msg of this ErrorDetail.
        :rtype: str
        """
        return self._error_msg

    @error_msg.setter
    def error_msg(self, error_msg):
        """Sets the error_msg of this ErrorDetail.

        |参数名称：返回码描述| |参数的约束及描述：该参数非必填，最大长度1024|

        :param error_msg: The error_msg of this ErrorDetail.
        :type: str
        """
        self._error_msg = error_msg

    @property
    def id(self):
        """Gets the id of this ErrorDetail.

        |参数名称：标示ID| |参数的约束及描述：该参数非必填，最大长度256|

        :return: The id of this ErrorDetail.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ErrorDetail.

        |参数名称：标示ID| |参数的约束及描述：该参数非必填，最大长度256|

        :param id: The id of this ErrorDetail.
        :type: str
        """
        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ErrorDetail):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
